@@ -16,11 +16,11 @@ Net::Dropbox::API - A dropbox API interface
 
 =head1 VERSION
 
-Version 1.3.2.1
+Version 1.4.3
 
 =cut
 
-our $VERSION = '1.3';
+our $VERSION = '1.4';
 
 
 =head1 SYNOPSIS
@@ -32,13 +32,15 @@ This is how it works:
     use Net::Dropbox::API;
 
     my $box = Net::Dropbox::API->new({key => 'KEY', secret => 'SECRET'});
-    my $login_link = $box->login;  # user needs to klick this link and login
+    my $login_link = $box->login;  # user needs to click this link and login
     $box->auth;                    # oauth keys get exchanged
     my $info = $box->account_info; # and here we have our account info
 
 See the examples for a working Mojolicious web client using the Dropbox
 API.
 
+You can find Dropbox's API documentation at L<https://www.dropbox.com/developers/web_docs>
+
 =head1 FUNCTIONS
 
 =cut
@@ -59,7 +61,7 @@ has 'context' => (is => 'rw', isa => 'Str', default => 'sandbox');
 =head2 login
 
 This sets up the initial OAuth handshake and returns the login URL. This
-URL has to be clicked by the user and the the user then has to accept
+URL has to be clicked by the user and the user then has to accept
 the application in dropbox. 
 
 Dropbox then redirects back to the callback URL defined with
@@ -76,7 +78,7 @@ sub login {
     my $request = Net::OAuth->request("request token")->new(
         consumer_key => $self->key,
         consumer_secret => $self->secret,
-        request_url => 'http://api.dropbox.com/0/oauth/request_token',
+        request_url => 'https://api.dropbox.com/0/oauth/request_token',
         request_method => 'POST',
         signature_method => 'HMAC-SHA1',
         timestamp => time,
@@ -117,7 +119,7 @@ sub auth {
     my $request = Net::OAuth->request("access token")->new(
         consumer_key => $self->key,
         consumer_secret => $self->secret,
-        request_url => 'http://api.dropbox.com/0/oauth/access_token',
+        request_url => 'https://api.dropbox.com/0/oauth/access_token',
         request_method => 'POST',
         signature_method => 'HMAC-SHA1',
         timestamp => time,
@@ -296,6 +298,13 @@ get a file from dropbox
 
 =cut
 
+=head2 debug
+
+Set this to a non-false value in order to print some debugging information to STDOUT.
+    debug(1)
+
+=cut
+
 sub getfile {
     my $self = shift;
     my $path = shift || '';
@@ -337,7 +346,7 @@ sub _talk {
     my %opts = (
         consumer_key => $self->key,
         consumer_secret => $self->secret,
-        request_url => 'http://'.$api.'.dropbox.com/0/'.$command,
+        request_url => 'https://'.$api.'.dropbox.com/0/'.$command,
         request_method => $method,
         signature_method => 'HMAC-SHA1',
         timestamp => time,
@@ -375,10 +384,6 @@ sub _talk {
     return;
 }
 
-=head2 talk
-
-=cut
-
 =head1 AUTHOR
 
 Lenz Gschwendtner, C<< <norbu09 at cpan.org> >>
@@ -391,10 +396,12 @@ Chris Prather C<< chris at prather.org >>
 
 Shinichiro Aska
 
+[ktdreyer]
+
 =head1 BUGS
 
-Please report any bugs or feature requests to C<bug-net-dropbox-api at rt.cpan.org>, or through
-the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Net-Dropbox-API>.  I will be notified, and then you'll
+Please report any bugs through the web interface at
+L<https://github.com/norbu09/Net--Dropbox/issues>.  I will be notified, and then you'll
 automatically be notified of progress on your bug as I make changes.
 
 =head1 SUPPORT
@@ -407,10 +414,6 @@ You can also look for information at:
 
 =over 4
 
-=item * RT: CPAN's request tracker
-
-L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=Net-Dropbox-API>
-
 =item * AnnoCPAN: Annotated CPAN documentation
 
 L<http://annocpan.org/dist/Net-Dropbox-API>
